Documentation
¶
Overview ¶
Package asyncprocessor contains an asynchronous processor.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Processor ¶
type Processor struct {
BufferSize int
OnError func(context.Context, error)
// contains filtered or unexported fields
}
Processor is an asynchronous queue processor that allows to detach the routine that is reading a stream from the routine that is writing a stream.
func (*Processor) Initialize ¶
func (w *Processor) Initialize()
Initialize initializes the processor.
Click to show internal directories.
Click to hide internal directories.